@@ -143,8 +143,8 @@ class AnalysisForm(forms.Form):
             wanted_fields.extend(['PhonoStatsBlickPhono'])
         if 'VP' in form['phonotactic']:
             wanted_fields.extend(['PhonoStatsSPhoneProb','PhonoStatsBiPhoneProb'])
-        for w in form['sem_pred_window']:
-            for s in form['sem_pred_style']:
+        for w in list(form['sem_pred_window']):
+            for s in list(form['sem_pred_style']):
                 if form['prev_sem_pred']:
                     wanted_fields.extend(['%sWindowPrev%sSemPred' %(w,s)])
                 if form['foll_sem_pred']:
