@@ -1021,8 +1021,8 @@ class WordToken(models.Model):
             if 'PhonoStatsSPhoneProb' not in outline:
                 outline['PhonoStatsSPhoneProb'],outline['PhonoStatsBiPhoneProb'] = getPhonotacticProb(self.WordType.getStrUR(),use_blick=False,no_stress=True)
 
-        for w in form['sem_pred_window']:
-            for s in form['sem_pred_style']:
+        for w in list(form['sem_pred_window']):
+            for s in list(form['sem_pred_style']):
                 if form['prev_sem_pred']:
                     label = '%sWindowPrev%sSemPred' %(w,s)
                     if label not in outline:
